use axum::{
    routing::{get, post},
    Router,
};
use std::sync::Arc;
use tokio::sync::Mutex;
use tower_http::cors::CorsLayer;

use super::handlers::{
    create_wallet, get_balance, get_blockchain_info, mine_block, send_transaction,
    SharedBlockchain,
};
use crate::blockchain::Blockchain;

pub async fn run_api_server(blockchain: Blockchain, port: u16) {
    let shared_blockchain = Arc::new(Mutex::new(blockchain));

    let app = Router::new()
        .route("/api/balance/:address", get(get_balance))
        .route("/api/info", get(get_blockchain_info))
        .route("/api/wallet", post(create_wallet))
        .route("/api/transaction", post(send_transaction))
        .route("/api/mine/:address", post(mine_block))
        .layer(CorsLayer::permissive())
        .with_state(shared_blockchain);

    let addr = format!("0.0.0.0:{}", port);
    println!("API server running on http://{}", addr);

    let listener = tokio::net::TcpListener::bind(&addr)
        .await
        .expect("Failed to bind");
        
    axum::serve(listener, app)
        .await
        .expect("Failed to start server");
}