use clap::{Parser, Subcommand};

#[derive(Parser)]
#[command(name = "aicoin")]
#[command(about = "AI Coin - Blockchain for AIverse", long_about = None)]
pub struct Cli {
    #[command(subcommand)]
    pub command: Commands,
}

#[derive(Subcommand)]
pub enum Commands {
    #[command(about = "Create a new wallet")]
    Wallet {
        #[arg(long, help = "ATProto DID for account linking")]
        atproto_did: Option<String>,
        #[arg(long, help = "Export wallet to file")]
        export: Option<String>,
    },
    
    #[command(about = "Import wallet from file")]
    Import {
        #[arg(help = "Path to wallet file")]
        path: String,
    },
    
    #[command(about = "Get balance of an address")]
    Balance {
        #[arg(help = "Wallet address")]
        address: String,
    },
    
    #[command(about = "Send coins to another address")]
    Send {
        #[arg(help = "Recipient address")]
        to: String,
        #[arg(help = "Amount to send")]
        amount: f64,
        #[arg(long, help = "Private key for signing")]
        private_key: String,
        #[arg(long, help = "ATProto DID")]
        atproto_did: Option<String>,
    },
    
    #[command(about = "Mine pending transactions")]
    Mine {
        #[arg(help = "Miner address")]
        address: String,
    },
    
    #[command(about = "Show blockchain info")]
    Info,
    
    #[command(about = "Validate blockchain")]
    Validate,
    
    #[command(about = "Start API server")]
    Server {
        #[arg(short, long, default_value = "8080", help = "API server port")]
        port: u16,
    },
    
    #[command(about = "Start P2P node")]
    Node {
        #[arg(short, long, default_value = "9000", help = "P2P network port")]
        port: u16,
    },
}